@@ -4,6 +4,7 @@ This module contains helper functions to manipulate videos
 @authors: Gergo Turi gt2253@cumc.columbia.edu
 """
 import os
+import copy
 import numpy as np
 import pandas as pd
 import statsmodels.api as sm
@@ -14,6 +15,14 @@ import analysis.roi_tools as rt
 import analysis.visualize as vis
 
 
+def mount_gdrive():
+    """
+    mounts Google Drive in a Google Colab notebook
+    """
+    from google.colab import drive
+    drive.mount('/content/drive')
+
+
 def get_fps(vid_path):
     """
     retrieves acqusition rate from AVI video.
@@ -50,9 +59,8 @@ def load_tracking(tracking_path):
     t = pd.read_hdf(tracking_path)
     if len(t.columns.names)==3:
         t.columns = t.columns.droplevel(0)
-    tracking = t
-    
-    return tracking
+        
+    return t
 
 def in_zone_oft(x, y, rois):
     """
@@ -137,7 +145,7 @@ def oft_pixel_to_cm(rois, dlc_tracking,
     rois: list of tuples
         the coordinates defining the ROIs
     dlc_tracking: pandas dataframe
-        contains the tracing info
+        contains the tracking info
     floor_length: int
         the lenght of the arena in cm
 
